@@ -8,7 +8,7 @@ macroblock_count = 33
 dtype = numpy.float32
 total_size = local_size*thread_strides*macroblock_count
 
-ctx = cl.Context()
+ctx = cl.create_some_context()
 queue = cl.CommandQueue(ctx)
 
 a = numpy.random.randn(total_size).astype(dtype)
@@ -44,9 +44,8 @@ rendered_tpl = tpl.render(type_name="float",
 
 knl = cl.Program(ctx, str(rendered_tpl)).build().add
 
-knl(queue, (local_size*macroblock_count,), 
-        c_buf, a_buf, b_buf, 
-        local_size=(local_size,))
+knl(queue, (local_size*macroblock_count,), (local_size,),
+        c_buf, a_buf, b_buf)
 
 c = numpy.empty_like(a)
 cl.enqueue_read_buffer(queue, c_buf, c).wait()
